==> apropos_ai-0.2.22.tar.gz: apropos_ai-0.2.22/apropos/src/core/lms/vendors/openai_like.py <==
import backoff
import groq
import instructor
import openai
import together
from apropos.src.core.lms.cache_init import cache, threaded_cache
from apropos.src.core.lms.vendors.base import BaseProvider

BACKOFF_TOLERANCE = 200


class OpenAIStandardProvider(BaseProvider):
    def __init__(self, sync_client, async_client):
        self.sync_client = sync_client
        self.async_client = async_client
        self.supports_response_model = False
        self.multi_threaded = False

    def hit_cache(self, messages, model, temperature, response_model):
        if self.multi_threaded:
            return threaded_cache.hit_cache(messages, model, temperature, response_model)
        else:
            return cache.hit_cache(messages, model, temperature, response_model)
    
    def add_to_cache(self, messages, model, temperature, response_model, content):
        if self.multi_threaded:
            return threaded_cache.add_to_cache(messages, model, temperature, response_model, content)
        else:
            return cache.add_to_cache(messages, model, temperature, response_model, content)

    
    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),  # pydantic_core._pydantic_core.ValidationError
        max_tries=BACKOFF_TOLERANCE,
    )
    def sync_chat_completion_with_response_model(
        self, messages, model, temperature, max_tokens, response_model
    ):
        if not self.supports_response_model:
            raise ValueError(
                "Code for this provider does not yet support response models"
            )
        # hit = safecache_wrapper.hit_cache(messages, model, temperature, response_model, cache, old_cache)
        hit = cache.hit_cache(messages, model, temperature, response_model)
        if hit:
            return hit
        output = self.sync_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
            response_model=response_model,
        )
        cache.add_to_cache(
            messages,
            model,
            temperature,
            response_model,
            output.choices[0].message.content,
        )
        # safecache_wrapper.add_to_cache(messages, model, temperature, response_model, output.choices[0].message.content, cache)
        return output.choices[0].message.content

    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            together.error.Timeout,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),  # pydantic_core._pydantic_core.ValidationError,
        max_tries=BACKOFF_TOLERANCE,
    )
    async def async_chat_completion_with_response_model(
        self, messages, model, temperature, max_tokens, response_model
    ):
        if not self.supports_response_model:
            raise ValueError(
                "Code for this provider does not yet support response models"
            )
        # hit = safecache_wrapper.hit_cache(messages, model, temperature,  response_model, cache, old_cache)
        # hit = cache.hit_cache(messages, model, temperature, response_model)
        hit = self.hit_cache(messages, model, temperature, response_model)
        # print("Hit true/false: ",hit is not None)
        if hit:
            return hit
        output = await self.async_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
            response_model=response_model,
        )
        # safecache_wrapper.add_to_cache(messages, model, temperature,  response_model, output.choices[0].message.content, cache)
        # cache.add_to_cache(
        #     messages,
        #     model,
        #     temperature,
        #     response_model,
        #     output.choices[0].message.content,
        # )
        self.add_to_cache(
            messages,
            model,
            temperature,
            response_model,
            output.choices[0].message.content,
        )
        return output.choices[0].message.content

    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            together.error.Timeout,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),
        max_tries=BACKOFF_TOLERANCE,
    )
    def sync_chat_completion(self, messages, model, temperature, max_tokens):
        # hit = cache.hit_cache(messages, model, temperature, None)
        hit = self.hit_cache(messages, model, temperature, None)
        if hit:
            return hit
        output = self.sync_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
        )
        # cache.add_to_cache(
        #     messages, model, temperature, None, output.choices[0].message.content
        # )
        self.add_to_cache(
            messages, model, temperature, None, output.choices[0].message.content
        )
        return output.choices[0].message.content

    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            together.error.Timeout,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),
        max_tries=BACKOFF_TOLERANCE,
    )
    async def async_chat_completion(self, messages, model, temperature, max_tokens):
        # hit = safecache_wrapper.hit_cache(messages, model, temperature, None, cache, old_cache)
        # hit = cache.hit_cache(messages, model, temperature, None)
        hit = self.hit_cache(messages, model, temperature, None)
        if hit:
            return hit
        output = await self.async_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
        )
        # safecache_wrapper.add_to_cache(messages, model, temperature, None, output.choices[0].message.content, cache)
        # cache.add_to_cache(
        #     messages, model, temperature, None, output.choices[0].message.content
        # )
        self.add_to_cache(
            messages, model, temperature, None, output.choices[0].message.content
        )
        return output.choices[0].message.content

==> apropos_ai-0.2.27.tar.gz: apropos_ai-0.2.27/apropos/src/core/lms/vendors/openai_like.py <==
import backoff
import groq
import instructor
import openai
import together
from apropos.src.core.lms.cache_init import cache, threaded_cache
from apropos.src.core.lms.vendors.base import BaseProvider

BACKOFF_TOLERANCE = 200


class OpenAIStandardProvider(BaseProvider):
    def __init__(self, sync_client, async_client, multi_threaded=False):
        self.sync_client = sync_client
        self.async_client = async_client
        self.supports_response_model = False
        self.multi_threaded = multi_threaded

    def hit_cache(self, messages, model, temperature, response_model):
        if self.multi_threaded:
            return threaded_cache.hit_cache(messages, model, temperature, response_model)
        else:
            return cache.hit_cache(messages, model, temperature, response_model)
    
    def add_to_cache(self, messages, model, temperature, response_model, content):
        if self.multi_threaded:
            return threaded_cache.add_to_cache(messages, model, temperature, response_model, content)
        else:
            return cache.add_to_cache(messages, model, temperature, response_model, content)

    
    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),  # pydantic_core._pydantic_core.ValidationError
        max_tries=BACKOFF_TOLERANCE,
    )
    def sync_chat_completion_with_response_model(
        self, messages, model, temperature, max_tokens, response_model
    ):
        if not self.supports_response_model:
            raise ValueError(
                "Code for this provider does not yet support response models"
            )
        # hit = safecache_wrapper.hit_cache(messages, model, temperature, response_model, cache, old_cache)
        hit = cache.hit_cache(messages, model, temperature, response_model)
        if hit:
            return hit
        output = self.sync_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
            response_model=response_model,
        )
        cache.add_to_cache(
            messages,
            model,
            temperature,
            response_model,
            output.choices[0].message.content,
        )
        # safecache_wrapper.add_to_cache(messages, model, temperature, response_model, output.choices[0].message.content, cache)
        return output.choices[0].message.content

    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            together.error.Timeout,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),  # pydantic_core._pydantic_core.ValidationError,
        max_tries=BACKOFF_TOLERANCE,
    )
    async def async_chat_completion_with_response_model(
        self, messages, model, temperature, max_tokens, response_model
    ):
        if not self.supports_response_model:
            raise ValueError(
                "Code for this provider does not yet support response models"
            )
        # hit = safecache_wrapper.hit_cache(messages, model, temperature,  response_model, cache, old_cache)
        # hit = cache.hit_cache(messages, model, temperature, response_model)
        hit = self.hit_cache(messages, model, temperature, response_model)
        # print("Hit true/false: ",hit is not None)
        if hit:
            return hit
        output = await self.async_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
            response_model=response_model,
        )
        # safecache_wrapper.add_to_cache(messages, model, temperature,  response_model, output.choices[0].message.content, cache)
        # cache.add_to_cache(
        #     messages,
        #     model,
        #     temperature,
        #     response_model,
        #     output.choices[0].message.content,
        # )
        self.add_to_cache(
            messages,
            model,
            temperature,
            response_model,
            output.choices[0].message.content,
        )
        return output.choices[0].message.content

    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            together.error.Timeout,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),
        max_tries=BACKOFF_TOLERANCE,
    )
    def sync_chat_completion(self, messages, model, temperature, max_tokens):
        # hit = cache.hit_cache(messages, model, temperature, None)
        hit = self.hit_cache(messages, model, temperature, None)
        if hit:
            return hit
        output = self.sync_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
        )
        # cache.add_to_cache(
        #     messages, model, temperature, None, output.choices[0].message.content
        # )
        self.add_to_cache(
            messages, model, temperature, None, output.choices[0].message.content
        )
        return output.choices[0].message.content

    @backoff.on_exception(
        backoff.expo,
        (
            openai.RateLimitError,
            together.error.RateLimitError,
            together.error.Timeout,
            groq.RateLimitError,
            instructor.exceptions.InstructorRetryException,
            together.error.APIConnectionError,
            together.error.APIError,
        ),
        max_tries=BACKOFF_TOLERANCE,
    )
    async def async_chat_completion(self, messages, model, temperature, max_tokens):
        # hit = safecache_wrapper.hit_cache(messages, model, temperature, None, cache, old_cache)
        # hit = cache.hit_cache(messages, model, temperature, None)
        hit = self.hit_cache(messages, model, temperature, None)
        if hit:
            return hit
        output = await self.async_client.chat.completions.create(
            model=model,
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
        )
        # safecache_wrapper.add_to_cache(messages, model, temperature, None, output.choices[0].message.content, cache)
        # cache.add_to_cache(
        #     messages, model, temperature, None, output.choices[0].message.content
        # )
        self.add_to_cache(
            messages, model, temperature, None, output.choices[0].message.content
        )
        return output.choices[0].message.content
